Crate gol_engines

Crate gol_engines 

Structs

BigInt
A big signed integer type.
Pattern
Represents a Game of Life pattern using a memory-efficient quadtree structure.
SIMDEngine
A fast, SIMD-optimized engine for Conway’s Game of Life that uses bitwise operations for efficient cell state updates. Its performance is pattern-oblivious.
StreamLifeEngineAsync
Implementation of StreamLife algorithm.
StreamLifeEngineSmall
Implementation of StreamLife algorithm.
StreamLifeEngineSync
Implementation of StreamLife algorithm.

Enums

PatternFormat
Supported formats for pattern serialization and deserialization.
PatternNode
A node is either a leaf (8x8 cells) or a non-leaf (4x4 nodes). Cells in the leaf are stored as a 64-bit integer in row-major order.
Topology
Describes the strategy of updating the field.

Constants

MAX_TASKS_COUNT
MIN_TASK_SPAWN_SHIFT
VERSION

Statics

TASKS_SPAWN_COUNT
WORKER_THREADS

Traits

GoLEngine
Game engine for Game of Life

Type Aliases

DefaultEngine
HashLifeEngineAsync
HashLifeEngineSmall
HashLifeEngineSync