Structs
- BigInt
- A big signed integer type.
- Pattern
- Represents a Game of Life pattern using a memory-efficient quadtree structure.
- SIMD
Engine - A fast, SIMD-optimized engine for Conway’s Game of Life that uses bitwise operations for efficient cell state updates. Its performance is pattern-oblivious.
- Stream
Life Engine Async - Implementation of StreamLife algorithm.
- Stream
Life Engine Small - Implementation of StreamLife algorithm.
- Stream
Life Engine Sync - Implementation of StreamLife algorithm.
Enums
- Pattern
Format - Supported formats for pattern serialization and deserialization.
- Pattern
Node - A node is either a leaf (8x8 cells) or a non-leaf (4x4 nodes). Cells in the leaf are stored as a 64-bit integer in row-major order.
- Topology
- Describes the strategy of updating the field.
Constants
Statics
Traits
- GoLEngine
- Game engine for Game of Life